@@ -87,7 +87,7 @@ public class AttributeMetadataHandler extends ParseSax.HandlerForGeneratedReques
     * {@inheritDoc}
     */
    @Override
-   public void characters(char ch[], int start, int length) {
+   public void characters(char[] ch, int start, int length) {
       currentText.append(ch, start, length);
    }
 
